@@ -577,7 +577,7 @@ set_info_items (GtkWidget *info_box, GSList *info_items)
 			image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_ERROR, GTK_ICON_SIZE_SMALL_TOOLBAR);
 			break;
 		case SUNONE_ITIP_VIEW_INFO_ITEM_TYPE_PROGRESS:
-			image = e_icon_factory_get_image ("stock_animation", E_ICON_SIZE_BUTTON);
+			image = gtk_image_new_from_icon_name ("stock_animation", GTK_ICON_SIZE_BUTTON);
 			break;
 		case SUNONE_ITIP_VIEW_INFO_ITEM_TYPE_NONE:
 		default:
@@ -687,7 +687,7 @@ sunone_itip_view_init (SunOneItipView *view)
 	gtk_box_set_spacing (GTK_BOX (view), 12);
 
 	/* The meeting icon */
-	icon = e_icon_factory_get_image (MEETING_ICON, E_ICON_SIZE_LARGE_TOOLBAR);
+	icon = gtk_image_new_from_icon_name (MEETING_ICON, GTK_ICON_SIZE_LARGE_TOOLBAR);
 	gtk_misc_set_alignment (GTK_MISC (icon), 0.5, 0);
 	gtk_widget_show (icon);
 
